Name:           courier-authlib
Version:        0.72.1
Release:        %mkrel 3
Summary:        Courier authentication library
Group:          System/Servers
License:        GPLv3
URL:            https://www.courier-mta.org/authlib/
Source0:        https://downloads.sourceforge.net/courier/%{name}-%{version}.tar.bz2
Source1:        courier-authlib.sysconftool.m4
Source2:        courier-authdaemon.service
Patch0:         courier-authlib-0.58.sysconftool.patch
BuildRequires:  expect
BuildRequires:  libltdl-devel
BuildRequires:  gdbm-devel
BuildRequires:  openldap-devel
BuildRequires:  pam-devel
BuildRequires:  mysql-devel
BuildRequires:  postgresql-devel
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  courier-unicode-devel
BuildRequires:  pkgconfig(libidn2)

%description
The Courier authentication library provides authentication
services for other Courier applications.

This package contains the Courier authentication daemon and common
authentication modules:

 o authcustom
 o authpam
 o authpwd
 o authshadow
 o courierauthsaslclient
 o courierauthsasl

%package -n courier-authdaemon
Summary:        Courier authentication daemon
Group:          System/Servers
Requires:       %{name} = %{version}
Requires:       expect
Requires(post): systemd >= %{systemd_required_version}
Requires(pre):  rpm-helper

%description -n courier-authdaemon
This package contains the Courier authentication daemon.

%package userdb
Summary:        Userdb support for the Courier authentication library
Group:          System/Servers
Requires(pre):  %{name} = %{version}

%description userdb
This package installs the userdb support for the Courier
authentication library.  Userdb is a simple way to manage virtual
mail accounts using a GDBM-based database file.

Install this package in order to be able to authenticate with
userdb.

%package ldap
Summary:        LDAP support for the Courier authentication library
Group:          System/Servers
Requires(pre):  %{name} = %{version}

%description ldap
This package installs LDAP support for the Courier authentication
library. Install this package in order to be able to authenticate
using LDAP.

%package mysql
Summary:        MySQL support for the Courier authentication library
Group:          System/Servers
Requires(pre):  %{name} = %{version}

%description mysql
This package installs MySQL support for the Courier authentication
library. Install this package in order to be able to authenticate
using MySQL.

%package pgsql
Summary:        MySQL support for the Courier authentication library
Group:          System/Servers
Requires(pre):  %{name} = %{version}

%description pgsql
This package installs PostgreSQL support for the Courier
authentication library. Install this package in order to be able
to authenticate using PostgreSQL.

%package sqlite
Summary:        SQLite support for the Courier authentication library
Group:          System/Servers
Requires(pre):  %{name} = %{version}

%description sqlite
This package installs sqlite support for the Courier
authentication library. Install this package in order to be able to
authenticate using SQLite.

%package devel
Summary:        Development libraries for the Courier authentication library
Group:          Development/C
Requires:       %{name} = %{version}

%description devel
This package contains the development libraries and files needed
to compile Courier packages that use this authentication library.
Install this package in order to build the rest of the Courier
packages. After they are built and installed this package can be
removed. Files in this package are not needed at runtime.

%prep
%setup -q
%patch -P 0 -p0 -b .sysconftool

install -Dpm644 %{SOURCE1} sysconftool.m4

%build
autoreconf -vfi -I.
%configure \
    --disable-static \
    --with-syslog=MAIL \
    --disable-ltdl-install \
    --with-db=gdbm \
    --with-random=/dev/urandom \
    --with-mailuser=daemon \
    --with-mailgroup=daemon \
    --with-authdaemonrc=%{_sysconfdir}/courier/authdaemonrc \
    --with-authdaemonvar=%{_rundir}/courier/authdaemon \
    --with-makedatprog=%{_sbindir}/makedatprog \
    --with-userdb=%{_sysconfdir}/userdb \
    --with-pkgconfdir=%{_sysconfdir}/courier \
    --with-authuserdb \
    --with-authpam \
    --with-authldap \
    --with-authldaprc=%{_sysconfdir}/courier/authldaprc \
    --with-authpwd \
    --with-authshadow \
    --without-authvchkpw \
    --with-authpgsqlrc=%{_sysconfdir}/courier/authpgsqlrc \
    --with-authpgsql \
    --with-pgsql-libs=%{_libdir} \
    --with-pgsql-includes=%{_includedir}/pgsql \
    --with-authmysqlrc=%{_sysconfdir}/courier/authmysqlrc \
    --with-authmysql \
    --with-mysql-libs=%{_libdir} \
    --with-mysql-includes=%{_includedir}/mysql \
    --with-authcustom
%make_build
#make_build authinfo

%check
%{__make} check

%install
%make_install

find %{buildroot} -name '*.la' -delete

install -m 755 sysconftool %{buildroot}%{_libdir}/courier-authlib/

install -d -m 755 %{buildroot}%{_unitdir}
install -m 644 %{SOURCE2} %{buildroot}%{_unitdir}/courier-authdaemon.service
mv %{buildroot}%{_libexecdir}/courier-authlib/authdaemond %{buildroot}%{_sbindir}/authdaemond

mv %{buildroot}%{_libexecdir}/courier-authlib/makedatprog %{buildroot}%{_sbindir}/makedatprog

# some utils...
# install -m 755 authinfo %%{buildroot}%%{_sbindir}/
#install -m 755 authdaemontest %%{buildroot}%%{_sbindir}/
#install -m 755 liblock/lockmail %%{buildroot}%%{_sbindir}/
#install -m 644 liblock/lockmail.1 %%{buildroot}%%{_mandir}/man1/

# fix configuration
for file in %{buildroot}%{_sysconfdir}/courier/*.dist; do
    mv $file  %{buildroot}%{_sysconfdir}/courier/`basename $file .dist`
done
chmod 644 %{buildroot}%{_sysconfdir}/courier/*

perl -pi \
    -e "s|^authmodulelist=.*|authmodulelist=\"authpam authpwd authshadow\"|g;" \
    -e "s|^authmodulelistorig=.*|authmodulelistorig=\"authpam authpwd authshadow\"|g;" \
    %{buildroot}%{_sysconfdir}/courier/authdaemonrc

cat > README.mga << EOF
Mageia RPM specific notes

Upgrade
------
Default upgrade procedure consists of shipping new configuration files with
.dist suffix, then running sysconftool script to merge with current
configuration. This packages ships new configuration files with their final
name instead, wich will be saved by rpm as .rpmnew if original ones have been
modified, and run sysconftools script during upgrade automatically.
EOF

# Fix path to libs
cat > courier-authlib.conf << EOF
%{_libdir}/courier-authlib
EOF
install -d %{buildroot}%{_sysconfdir}/ld.so.conf.d
install -m 755 courier-authlib.conf %{buildroot}%{_sysconfdir}/ld.so.conf.d

mkdir -p %{buildroot}%{_tmpfilesdir}
cat <<EOF > %{buildroot}%{_tmpfilesdir}/%{name}.conf
#Type Path                    Mode UID     GID     Age Argument
    d /run/courier            0775 root    courier -   -
    d /run/courier/authdaemon 0750 courier courier -   -
EOF

install -d -m 0755 %{buildroot}%{_rundir}/courier/authdaemon

%post -n courier-authdaemon
if [ -f %{_sysconfdir}/courier/authdaemonrc.rpmnew ]; then
    %{_libdir}/courier-authlib/sysconftool %{_sysconfdir}/courier/authdaemonrc.rpmnew >/dev/null
fi
%_tmpfilescreate %{name}
%_post_service courier-authdaemon

%preun -n courier-authdaemon
%_preun_service courier-authdaemon

%post ldap
if [ -f %{_sysconfdir}/courier/authldaprc.rpmnew ]; then
    %{_libdir}/courier-authlib/sysconftool %{_sysconfdir}/courier/authldaprc.rpmnew >/dev/null
fi

%post mysql
if [ -f %{_sysconfdir}/courier/authmysqlrc.rpmnew ]; then
    %{_libdir}/courier-authlib/sysconftool %{_sysconfdir}/courier/authmysqlrc.rpmnew >/dev/null
fi

%files
%license COPYING*
%doc README.mga README README.authdebug.html README.html README_authlib.html
%doc NEWS AUTHORS ChangeLog
%dir %{_sysconfdir}/courier
%dir %{_libdir}/courier-authlib
%dir %{_libexecdir}/courier-authlib
%{_sysconfdir}/ld.so.conf.d/courier-authlib.conf
%{_libexecdir}/courier-authlib/authsystem.passwd
%{_libdir}/courier-authlib/sysconftool
%{_libdir}/courier-authlib/libcourierauthsaslclient.so*
%{_libdir}/courier-authlib/libcourierauthsasl.so*
%{_libdir}/courier-authlib/libcourierauthcommon.so*
%{_libdir}/courier-authlib/libcourierauth.so*
%{_libdir}/courier-authlib/libauthcustom.so*
%{_libdir}/courier-authlib/libauthpam.so*
%{_libdir}/courier-authlib/libauthpwd.so*
%{_libdir}/courier-authlib/libauthshadow.so*
%{_libdir}/courier-authlib/libauthpipe.so*
%{_mandir}/man1/*

%files -n courier-authdaemon
%config(noreplace) %{_sysconfdir}/courier/authdaemonrc
%{_tmpfilesdir}/%{name}.conf
%{_sbindir}/authdaemond
%{_sbindir}/authenumerate
%{_sbindir}/authtest
%{_sbindir}/courierlogger
%{_sbindir}/authpasswd
%{_sbindir}/makedatprog
%{_unitdir}/courier-authdaemon.service
%dir %ghost %attr(0775, root, courier) %{_rundir}/courier
%dir %ghost %attr(0750, courier, courier) %{_rundir}/courier/authdaemon
%ghost %attr(0660, -, -) %{_rundir}/courier/authdaemon/authdaemon.pid

%files userdb
%doc userdb/makeuserdb.html userdb/userdb.html userdb/userdbpw.html
%{_sbindir}/makeuserdb
%{_sbindir}/pw2userdb
%{_sbindir}/userdb
%{_sbindir}/userdbpw
%{_libdir}/courier-authlib/libauthuserdb.so*
%{_mandir}/man8/*userdb*

%files ldap
%doc README.ldap authldap.schema
%config(noreplace) %{_sysconfdir}/courier/authldaprc
%{_libdir}/courier-authlib/libauthldap.so*

%files mysql
%doc README.authmysql.html README.authmysql.myownquery
%config(noreplace) %{_sysconfdir}/courier/authmysqlrc
%{_libdir}/courier-authlib/libauthmysql.so*

%files pgsql
%doc README.authpostgres.html
%config(noreplace) %{_sysconfdir}/courier/authpgsqlrc
%{_libdir}/courier-authlib/libauthpgsql.so*

%files sqlite
%doc README.authsqlite.html
%config(noreplace) %{_sysconfdir}/courier/authsqliterc
%{_libdir}/courier-authlib/libauthsqlite.so*

%files devel
%doc authlib.html auth_*.html
%{_bindir}/courierauthconfig
%{_includedir}/*
%{_mandir}/man3/*


%changelog
* Sun Jun 29 2025 umeabot <umeabot> 0.72.1-3.mga10
+ Revision: 2225123
- Mageia 10 Mass Rebuild

* Thu Jul 18 2024 daviddavid <daviddavid> 0.72.1-2.mga10
+ Revision: 2082060
- fix courier-authdaemon systemd service file (mga#33402)
+ wally <wally>
- update URL

* Wed Apr 17 2024 daviddavid <daviddavid> 0.72.1-1.mga10
+ Revision: 2058369
- new version: 0.72.1

* Wed Apr 17 2024 daviddavid <daviddavid> 0.72.0-2.mga10
+ Revision: 2058364
- switch to systemd unit from initscripts

* Thu Feb 02 2023 wally <wally> 0.72.0-1.mga9
+ Revision: 1937613
- new version 0.72.0

* Tue Jan 03 2023 umeabot <umeabot> 0.71.5-2.mga9
+ Revision: 1929534
- Rebuild to use libldap-2.5 instead of 2.4

* Fri Jun 24 2022 wally <wally> 0.71.5-1.mga9
+ Revision: 1865681
- new version 0.71.5
- build with libidn2
- no more authmigrate nor userdb-test-cram-md5 executables
- don't install authdaemontest
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild
+ mrambo3501 <mrambo3501>
- revert the rpath check disable

* Wed Mar 09 2022 mrambo3501 <mrambo3501> 0.70.0-2.mga9
+ Revision: 1790207
- disable rpath checking

* Wed Jun 03 2020 cheeseeboi <cheeseeboi> 0.70.0-1.mga8
+ Revision: 1590065
- updated to version 0.70.0

* Fri Feb 14 2020 umeabot <umeabot> 0.69.0-2.mga8
+ Revision: 1520455
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Thu Nov 22 2018 shlomif <shlomif> 0.69.0-1.mga7
+ Revision: 1333249
- New version 0.69.0

* Sun Sep 23 2018 umeabot <umeabot> 0.68.0-3.mga7
+ Revision: 1296841
- Mageia 7 Mass Rebuild

* Sun Jun 17 2018 luigiwalser <luigiwalser> 0.68.0-2.mga7
+ Revision: 1237480
- rebuild for gdbm

* Sat Dec 23 2017 wally <wally> 0.68.0-1.mga7
+ Revision: 1184370
- new version 0.68.0
- rebuild for new mariadb

* Sun Feb 28 2016 oden <oden> 0.66.4-3.mga6
+ Revision: 980335
- rebuilt for postgresql 9.5.x

* Mon Feb 08 2016 umeabot <umeabot> 0.66.4-2.mga6
+ Revision: 950861
- Mageia 6 Mass Rebuild

* Sat Feb 06 2016 wally <wally> 0.66.4-1.mga6
+ Revision: 942171
- new version 0.66.4
- add patch to fix linking

* Tue Nov 25 2014 cjw <cjw> 0.65.0-12.mga5
+ Revision: 799053
- rebuild against postgresql9.4

* Wed Oct 15 2014 umeabot <umeabot> 0.65.0-11.mga5
+ Revision: 743717
- Second Mageia 5 Mass Rebuild

* Fri Sep 26 2014 tv <tv> 0.65.0-10.mga5
+ Revision: 725008
- rebuild for bogus file deps

* Thu Sep 18 2014 umeabot <umeabot> 0.65.0-9.mga5
+ Revision: 693690
- Rebuild to fix library dependencies

* Tue Sep 16 2014 umeabot <umeabot> 0.65.0-8.mga5
+ Revision: 678558
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 0.65.0-7.mga4
+ Revision: 522621
- Mageia 4 Mass Rebuild

* Sun Mar 24 2013 colin <colin> 0.65.0-6.mga3
+ Revision: 404859
- Add systemd requires and general post/pre fixes (mga#9302)

* Sun Jan 13 2013 luigiwalser <luigiwalser> 0.65.0-5.mga3
+ Revision: 380025
- add tmpfiles config for /run/authdaemon

* Fri Jan 11 2013 umeabot <umeabot> 0.65.0-4.mga3
+ Revision: 348191
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Jan 01 2013 pterjan <pterjan> 0.65.0-3.mga3
+ Revision: 337446
- Fix for _libdir != _libexecdir

* Thu Oct 11 2012 oden <oden> 0.65.0-2.mga3
+ Revision: 304626
- fix #7727 ( courier-authlib-devel provides)

* Mon Oct 08 2012 barjac <barjac> 0.65.0-1.mga3
+ Revision: 303428
- New version 0.65.0
  Added sqlite sub-package
  Fixed unversioned explicit obsoletes
  Added BuildRequire sqlite3-devel

* Wed Aug 01 2012 sander85 <sander85> 0.64.0-1.mga3
+ Revision: 277335
- New version: 0.64.0

* Tue May 08 2012 pterjan <pterjan> 0.63.0-12.mga2
+ Revision: 234933
- Fix initscript's LSB header
+ guillomovitch <guillomovitch>
- rename distribution-specific documentation file to README.mga

* Tue Dec 06 2011 fwang <fwang> 0.63.0-11.mga2
+ Revision: 177156
- rebuild for new gdbm

* Sat Dec 03 2011 barjac <barjac> 0.63.0-10.mga2
+ Revision: 175716
- Removed ldconfig in %%post & %%postun

* Mon Nov 28 2011 barjac <barjac> 0.63.0-9.mga2
+ Revision: 173752
- Added ldconfig in %%post and %%postun

* Sun Nov 27 2011 shlomif <shlomif> 0.63.0-8.mga2
+ Revision: 173072
- Add lib path to ld.so.conf.d to fix dynamic linking compilation

* Wed Sep 21 2011 fwang <fwang> 0.63.0-7.mga2
+ Revision: 146384
- drop .la files

* Fri Mar 25 2011 dmorgan <dmorgan> 0.63.0-6.mga1
+ Revision: 77243
- Rebuild against new mysql

* Sun Feb 06 2011 spuhler <spuhler> 0.63.0-5.mga1
+ Revision: 47794
- removed buildroot definition from .spec
-Mandriva RPM specific notes
  +Mageia RPM specific notes
- imported package courier-authlib


* Sat Jan 01 2011 Oden Eriksson <oeriksson@mandriva.com> 0.63.0-5mdv2011.0
+ Revision: 627218
- rebuilt against mysql-5.5.8 libs, again

* Thu Dec 30 2010 Oden Eriksson <oeriksson@mandriva.com> 0.63.0-4mdv2011.0
+ Revision: 626512
- rebuilt against mysql-5.5.8 libs

* Sun Dec 05 2010 Oden Eriksson <oeriksson@mandriva.com> 0.63.0-2mdv2011.0
+ Revision: 610162
- rebuild

* Fri Feb 26 2010 Guillaume Rousse <guillomovitch@mandriva.org> 0.63.0-1mdv2010.1
+ Revision: 512127
- update to new version 0.63.0

* Thu Feb 18 2010 Oden Eriksson <oeriksson@mandriva.com> 0.62.4-2mdv2010.1
+ Revision: 507481
- rebuild

* Thu Jul 23 2009 Guillaume Rousse <guillomovitch@mandriva.org> 0.62.4-1mdv2010.0
+ Revision: 399045
- new version

* Sun Jan 18 2009 Guillaume Rousse <guillomovitch@mandriva.org> 0.62.0-1mdv2009.1
+ Revision: 331022
- update to new version 0.62.0

* Mon Dec 08 2008 Oden Eriksson <oeriksson@mandriva.com> 0.61.1-1mdv2009.1
+ Revision: 311851
- 0.61.1
- use lowercase mysql-devel

* Sat Dec 06 2008 Oden Eriksson <oeriksson@mandriva.com> 0.61.0-3mdv2009.1
+ Revision: 311327
- rebuilt against mysql-5.1.30 libs

* Mon Sep 08 2008 Guillaume Rousse <guillomovitch@mandriva.org> 0.61.0-2mdv2009.0
+ Revision: 282763
- use a rebind mount instead of an hard link for postfix chroot (bug #43478)
- change initscript to re-mount the socket directory in postfix chroot, as hardlinks don't work between different filesystems

* Sat Sep 06 2008 Guillaume Rousse <guillomovitch@mandriva.org> 0.61.0-1mdv2009.0
+ Revision: 281748
- new version

* Fri Jul 04 2008 Guillaume Rousse <guillomovitch@mandriva.org> 0.60.6-1mdv2009.0
+ Revision: 231884
- new version

  + Pixel <pixel@mandriva.com>
    - adapt to %%_localstatedir now being /var instead of /var/lib (#22312)

* Wed Dec 26 2007 Oden Eriksson <oeriksson@mandriva.com> 0.60.1-2mdv2008.1
+ Revision: 137976
- rebuilt against openldap-2.4.7 libs

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Thu Dec 13 2007 Guillaume Rousse <guillomovitch@mandriva.org> 0.60.1-1mdv2008.1
+ Revision: 119234
- update to new version 0.60.1


* Mon Mar 05 2007 Guillaume Rousse <guillomovitch@mandriva.org> 0.59.1-2mdv2007.0
+ Revision: 133179
- more consistent init scripts
- export DEBUG_LOGIN variable before launching daemon, as it seems to trust environment more than its configuration file (fix #28354)
- new version

* Fri Jan 12 2007 Guillaume Rousse <guillomovitch@mandriva.org> 0.59-1mdv2007.1
+ Revision: 107889
- new version
- Import courier-authlib

* Wed Sep 20 2006 Guillaume Rousse <guillomovitch@mandriva.org> 0.58-9mdv2007.0
- enforce courierlogger options in init script
- add network dependencies in init script

* Thu Aug 31 2006 Guillaume Rousse <guillomovitch@mandriva.org> 0.58-8mdv2007.0
- fix sysconftool patch
- fix config file merge in %%post
- add postfix chroot support in init script (#5134)
- decompress all patches and sources

* Wed May 24 2006 Guillaume Rousse <guillomovitch@mandriva.org> 0.58-7mdk
- fix buildrequires
- fix initscript

* Wed May 24 2006 Guillaume Rousse <guillomovitch@mandriva.org> 0.58-6mdk
- resurect authdaemon subpackage
- mv plugins in runtime packages
- mv configuration in /etc/courier

* Wed May 17 2006 Guillaume Rousse <guillomovitch@mandriva.org> 0.58-5mdk
- conflicts with old courier-imap release (fix bug #22476)
- obsoletes plugin packages previsouly shipped with courier-imap
- fix configure invocation
- fix some perms

* Mon May 15 2006 Guillaume Rousse <guillomovitch@mandriva.org> 0.58-4mdk
- drop vpopmail support
- minor initscript corrections

* Thu May 11 2006 Guillaume Rousse <guillomovitch@mandriva.org> 0.58-3mdk
- no need for libification
- rename courier-authdaemon to courier-authlib
- don't ship .dist configuration files, and patch sysconftool to handle .rpmnew instead
- spec cleanup
- LSB-compliant init script
- simpler %%post/%%pre scripts using condrestart
- don't ship socket in package

* Thu May 11 2006 Jerome Soyer <saispo@mandriva.org> 0.58-2mdk
- Remove not needed "%%pre"

* Wed May 10 2006 Jerome Soyer <saispo@mandriva.org> 0.58-1mdk
- New release 0.58
- Use mkrel

* Thu Apr 21 2005 Oden Eriksson <oeriksson@mandriva.com> 0.55-4mdk
- rebuilt against new postgresql libs

* Sun Mar 06 2005 Oden Eriksson <oeriksson@mandrakesoft.com> 0.55-3mdk
- fix some minor issues
- make it compile on 10.0 too (libtool mess)
- make it somewhat possible to link against vpopmail
- do some libifiction
- rename the initscript to courier-authdaemond

* Sat Mar 05 2005 Oden Eriksson <oeriksson@mandrakesoft.com> 0.55-2mdk
- fix deps

* Fri Mar 04 2005 Oden Eriksson <oeriksson@mandrakesoft.com> 0.55-1mdk
- 0.55

* Tue Mar 01 2005 Oden Eriksson <oeriksson@mandrakesoft.com> 0.54-1mdk
- initial Mandrakelinux package
- added a more standard initscript (S2)
- used tiny parts of the provided spec file

